… | OiRA

Help

1. Подготовка
2. Включване
3. Определяне + Оценяване
   1. 1 Commercial manned guarding
   2. Ω Добавени рискове (от Вас)
      1. Ω.1 The entrance floor is often wet
      2. Ω.2 …
   - Без отговор
   - Отложено разглеждане
   - Правилно
   - Внимание
4. План за действие
5. Доклад
6. Статус 0%

## Опишете риска…

Не, необходими са допълнителни мерки. Да, оставащият риск е приемлив.

Select the priority of this risk Low Medium High
Информация
Поставяне на изображениеlabel_upload_image
Коментари

Scroll to top
Back

## add-risk.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More